@@ -2,7 +2,7 @@
 #'
 #' @description \code{shem} estimates the number of principal components via Split-Half Eigenvector Matching (SHEM).
 #'
-#' @param data a data frame, a numeric matrix, covariance matrix or correlation matrix from which to determine the number of factors.
+#' @param .data a data frame, a numeric matrix, covariance matrix or correlation matrix from which to determine the number of factors.
 #' @param nIts number of iterations.
 #'
 #' @return \code{shem} returns a list containing the number of components, \code{nfactors}, whether the additional step in case of zero true latent components was carried, \code{zeroComponents}, the \code{eigenvalues} and the \code{eigenvectors} of the solution. 
@@ -17,8 +17,8 @@
 #' @examples
 #' jd <- genr8(n = 404, R = ex_4factors_corr)
 #' shem(jd)
-shem <- function(data, nIts = 30){
-  get_n_components(X = data, nIts)
+shem <- function(.data, nIts = 30){
+  get_n_components(X = .data, nIts)
 }
 
 # Similarity of eigenvectors over split-halves
